AccumulationLimit

Enum AccumulationLimit 

pub enum AccumulationLimit {
    Unlimited,
    Max(usize),
}
Controls how many items the decoder will accumulate in a multi-line response or >CLIENT: ENV block before returning an error.

Variants



Unlimited

No limit on accumulated items (the default).



Max(usize)

At most this many items before the decoder returns an error.