pub enum StreamMode {
On,
Off,
All,
OnAll,
Recent(u32),
}Expand description
Mode selector for commands that share the on/off/all/on-all/N grammar.
This is used by log, state, and echo, all of which support
identical sub-commands.
Variants
On
Enable real-time notifications.
Off
Disable real-time notifications.
All
Dump the entire history buffer.
OnAll
Atomically enable real-time notifications AND dump history. This guarantees no messages are missed between the dump and the start of real-time streaming.
Recent(u32)
Show the N most recent history entries.